@@ -164,7 +164,7 @@ class MyCache(apt.Cache):
                                len(reqreinst)) % ", ".join(reqreinst)
             if view.askYesNoQuestion(header, summary):
                 self.release_lock()
-                cmd = ["dpkg","--remove","--force-remove-reinstreq"] + list(reqreinst)
+                cmd = ["/usr/bin/dpkg","--remove","--force-remove-reinstreq"] + list(reqreinst)
                 view.getTerminal().call(cmd)
                 self.get_lock()
                 return True
@@ -531,57 +531,6 @@ class MyCache(apt.Cache):
         return False
 
 
-    def getKernelsFromBaseInstaller(self):
-        """get the list of recommended kernels from base-installer"""
-        p = Popen(["/bin/sh", "./get_kernel_list.sh"],
-                  stdout=PIPE, universal_newlines=True)
-        res = p.wait()
-        if res != 0:
-            logging.warn("./get_kernel_list.sh returned non-zero exitcode")
-            return ""
-        kernels = p.communicate()[0]
-        kernels = [x.strip() for x in kernels.split("\n")]
-        kernels = [x for x in kernels if len(x) > 0]
-        logging.debug("./get_kernel_list.sh returns: %s" % kernels)
-        return kernels
-
-    def _selectKernelFromBaseInstaller(self):
-        """ use the get_kernel_list.sh script (that uses base-installer)
-            to figure out what kernel is most suitable for the system
-        """
-        # check if we have a kernel from that list installed first
-        kernels = self.getKernelsFromBaseInstaller()
-        for kernel in kernels:
-            if not kernel in self:
-                logging.debug("%s not available in cache" % kernel)
-                continue
-            # this can happen e.g. on cdrom -> cdrom only upgrades
-            # where on hardy we have linux-386 but on the lucid CD 
-            # we only have linux-generic
-            if (not self[kernel].candidate or
-                not self[kernel].candidate.downloadable):
-                logging.debug("%s not downloadable" % kernel)
-                continue
-            # check if installed
-            if self[kernel].is_installed or self[kernel].marked_install:
-                logging.debug("%s kernel already installed" % kernel)
-                if self[kernel].is_upgradable and not self[kernel].marked_upgrade:
-                    self.mark_upgrade(kernel, "Upgrading kernel from base-installer")
-                return 
-        # if we have not found a kernel yet, use the first one that installs
-        for kernel in kernels:
-            if self.mark_install(kernel, 
-                                 "Selecting new kernel from base-installer"):
-                if self._has_kernel_headers_installed():
-                    prefix, sep, postfix = kernel.partition("-")
-                    headers = "%s-header-%s" % (prefix, postfix)
-                    self.mark_install(
-                        headers,
-                        "Selecting new kernel headers from base-installer")
-                else:
-                    logging.debug("no kernel-headers installed")
-                return
-
     def _has_kernel_headers_installed(self):
         for pkg in self:
             if (pkg.name.startswith("linux-headers-") and
@@ -603,11 +552,6 @@ class MyCache(apt.Cache):
         dmesg = Popen(["dmesg"],stdout=PIPE).communicate()[0]
         if b"WARNING: NR_CPUS limit" in dmesg:
             logging.debug("UP kernel on SMP system!?!")
-        # use base-installer to get the kernel we want (if it exists)
-        if os.path.exists("./get_kernel_list.sh"):
-            self._selectKernelFromBaseInstaller()
-        else:
-            logging.debug("skipping ./get_kernel_list.sh: not found")
         return True
 
     def checkPriority(self):
@@ -691,12 +635,12 @@ class MyCache(apt.Cache):
             t.join()
             # FIXME: change the text to something more useful
             details =  _("An unresolvable problem occurred while "
-                         "calculating the upgrade:\n%s\n\n "
+                         "calculating the upgrade.\n\n "
                          "This can be caused by:\n"
                          " * Upgrading to a pre-release version of Ubuntu\n"
                          " * Running the current pre-release version of Ubuntu\n"
                          " * Unofficial software packages not provided by Ubuntu\n"
-                         "\n") % e
+                         "\n")
             # we never have partialUpgrades (including removes) on a stable system
             # with only ubuntu sources so we do not recommend reporting a bug
             if partialUpgrade:
@@ -711,16 +655,16 @@ class MyCache(apt.Cache):
             view.error(_("Could not calculate the upgrade"), details)
             # start the resolver log again because this is run with
             # the withResolverLog decorator
-            self._startAptResolverLog()            
+            self._startAptResolverLog()
             logging.error("Dist-upgrade failed: '%s'", e)
             return False
         # would be nice to be able to use finally: here, but we need
-        # to run on python2.4 too 
+        # to run on python2.4 too
         #finally:
         # wait for the gui-update thread to exit
         lock.release()
         t.join()
-        
+
         # check the trust of the packages that are going to change
         untrusted = []
         for pkg in self.get_changes():
@@ -1150,7 +1094,9 @@ class MyCache(apt.Cache):
             if re.match("^linux-(image|image-debug)-[0-9.]*-.*", pkg.name):
                 if pkg.marked_install:
                     logging.debug("%s (new-install) added with %s to boot space" % (pkg.name, KERNEL_INITRD_SIZE))
-                    space_in_boot += KERNEL_INITRD_SIZE
+                    # multiply the KERNEL_INITRD_SIZE by two as we store a
+                    # copy of the old initrd when creating a new one
+                    space_in_boot += (KERNEL_INITRD_SIZE * 2)
                 # mvo: jaunty does not create .bak files anymore
                 #elif (pkg.marked_upgrade or pkg.is_installed):
                 #    logging.debug("%s (upgrade|installed) added with %s to boot space" % (pkg.name, KERNEL_INITRD_SIZE))
