@@ -2,18 +2,18 @@
 
 set -e
 
-dpkg-checkbuilddeps -d 'apt-btrfs-snapshot, parsewiki, python-feedparser,
-			python3-mock, xvfb, gir1.2-gtk-3.0, python-gi, python3-nose'
+# The testsuite has a sad if you're in a non-UTF-8 locale:
+export LANG='C.UTF-8'
+
+dpkg-checkbuilddeps -d 'python3-apt, apt-btrfs-snapshot, parsewiki, python-feedparser,
+			python3-mock, xvfb, gir1.2-gtk-3.0, python3-gi, python3-nose'
 
 # update demotions
-(cd utils && ./demotions.py precise quantal > demoted.cfg)
+(cd utils && ./demotions.py raring saucy > demoted.cfg)
 # when this gets enabled, make sure to add symlink in DistUpgrade
 #(cd utils && ./demotions.py lucid precise > demoted.cfg.lucid)
 
-# update base-installer
-(cd utils && ./update-base-installer.sh)
-
-# update apt_btrfs_snapshot.py copy, this nees a installed
+# update apt_btrfs_snapshot.py copy, this needs an installed
 # apt-btrfs-snapshot on the build machine
 if [ ! -e /usr/share/pyshared/apt_btrfs_snapshot.py ]; then
     echo "please sudo apt-get install apt-btrfs-snapshot"
@@ -36,7 +36,7 @@ fi
 rm -rf utils/apt/lists utils/apt/*.bin
 (cd utils && ./update_mirrors.py ../data/mirrors.cfg)
 
-# run the test-suit
+# run the test-suite
 #echo "Running integrated tests"
 nosetests3
 
